@@ -20,6 +20,7 @@ from pytype.abstract import mixin
 from pytype.overlays import typed_dict as typed_dict_overlay
 from pytype.pytd import escape
 from pytype.pytd import optimize
+from pytype.pytd import pytd
 from pytype.pytd import pytd_utils
 from pytype.pytd import slots
 from pytype.pytd import visitors
@@ -1005,6 +1006,8 @@ class ErrorLog(ErrorLogBase):
 
   def _show_variable(self, var):
     """Show variable as 'name: typ' or 'pyval: typ' if available."""
+    if not var.data:
+      return self._pytd_print(pytd.NothingType())
     val = var.data[0]
     name = val.ctx.vm.get_var_name(var)
     typ = self._join_printed_types(
@@ -1027,14 +1030,20 @@ class ErrorLog(ErrorLogBase):
   @_error_name("unsupported-operands")
   def _unsupported_operands(self, stack, operator, *operands, details=None):
     """Unsupported operands."""
-    args = " and ".join(str(operand) for operand in operands)
-    if operator in slots.COMPARES:
+    # `operator` is sometimes the symbol and sometimes the method name, so we
+    # need to check for both here.
+    # TODO(mdemello): This is a mess, we should fix the call sites.
+    if operator in slots.SYMBOL_MAPPING:
+      symbol = slots.SYMBOL_MAPPING[operator]
+    else:
       symbol = operator
+    cmp = operator in slots.COMPARES or symbol in slots.COMPARES
+    args = " and ".join(str(operand) for operand in operands)
+    if cmp:
       details = f"Types {args} are not comparable."
       self.error(stack, f"unsupported operand types for {symbol}",
                  details=details)
     else:
-      symbol = slots.SYMBOL_MAPPING[operator]
       self.error(stack, f"unsupported operand type(s) for {symbol}: {args}",
                  details=details)
 
