@@ -44,6 +44,7 @@ _NEWTYPE_IDS = ("NewType", "typing.NewType")
 _ANNOTATED_IDS = (
     "Annotated", "typing.Annotated", "typing_extensions.Annotated")
 _FINAL_IDS = ("typing.Final", "typing_extensions.Final")
+_TYPE_ALIAS_IDS = ("typing.TypeAlias", "typing_extensions.TypeAlias")
 
 #------------------------------------------------------
 # imports
@@ -414,18 +415,22 @@ class _GeneratePytdVisitor(visitor.BaseVisitor):
     typ = node.annotation
     val = self.convert_node(node.value)
     msg = f"Default value for {name}: {typ.name} can only be '...', got {val}"
-    if typ.name and pytd_utils.MatchesFullName(typ, _FINAL_IDS):
-      if isinstance(node.value, types.Pyval):
-        # to_pytd_literal raises an exception if the value is a float, but
-        # checking upfront allows us to generate a nicer error message.
-        if isinstance(node.value.value, float):
-          msg = (f"Default value for {name}: Final can only be '...' or a "
-                 f"legal Literal parameter, got {val}")
-        else:
-          typ = node.value.to_pytd_literal()
+    if typ.name:
+      if pytd_utils.MatchesFullName(typ, _FINAL_IDS):
+        if isinstance(node.value, types.Pyval):
+          # to_pytd_literal raises an exception if the value is a float, but
+          # checking upfront allows us to generate a nicer error message.
+          if isinstance(node.value.value, float):
+            msg = (f"Default value for {name}: Final can only be '...' or a "
+                   f"legal Literal parameter, got {val}")
+          else:
+            typ = node.value.to_pytd_literal()
+            val = pytd.AnythingType()
+        elif isinstance(val, pytd.NamedType):
+          typ = pytd.Literal(val)
           val = pytd.AnythingType()
-      elif isinstance(val, pytd.NamedType):
-        typ = pytd.Literal(val)
+      elif pytd_utils.MatchesFullName(typ, _TYPE_ALIAS_IDS):
+        typ = pytd.GenericType(pytd.NamedType("type"), (val,))
         val = pytd.AnythingType()
     if val and not types.is_any(val):
       raise ParseError(msg)
@@ -492,10 +497,9 @@ class _GeneratePytdVisitor(visitor.BaseVisitor):
   def enter_If(self, node):
     # Evaluate the test and preemptively remove the invalid branch so we don't
     # waste time traversing it.
-    node.test = conditions.evaluate(
-        node.test, self.options.python_version, self.options.platform)
+    node.test = conditions.evaluate(node.test, self.options)
     if not isinstance(node.test, bool):
-      raise ParseError("Unexpected if statement" + debug.dump(node, ast3))
+      raise ParseError("Unexpected if statement " + debug.dump(node, ast3))
 
     if node.test:
       node.orelse = []
@@ -504,7 +508,7 @@ class _GeneratePytdVisitor(visitor.BaseVisitor):
 
   def visit_If(self, node):
     if not isinstance(node.test, bool):
-      raise ParseError("Unexpected if statement" + debug.dump(node, ast3))
+      raise ParseError("Unexpected if statement " + debug.dump(node, ast3))
 
     if node.test:
       return Splice(node.body)
@@ -704,6 +708,7 @@ def _feature_version(python_version: Tuple[int, ...]) -> int:
 # Options that will be copied from pytype.config.Options.
 _TOPLEVEL_PYI_OPTIONS = (
     "python_version",
+    "strict_primitive_comparisons",
 )
 
 
@@ -713,6 +718,7 @@ class PyiOptions:
 
   python_version: Tuple[int, int] = sys.version_info[:2]
   platform: str = _DEFAULT_PLATFORM
+  strict_primitive_comparisons: bool = True
 
   @classmethod
   def from_toplevel_options(cls, toplevel_options):
